@@ -1,10 +1,46 @@
 -- 
 -- Created by SQL::Translator::Producer::SQLite
--- Created on Mon Aug  8 15:39:42 2011
+-- Created on Thu Feb 16 11:10:09 2012
 -- 
 
 BEGIN TRANSACTION;
 
+--
+-- Table: contact
+--
+DROP TABLE contact;
+
+CREATE TABLE contact (
+  id INTEGER PRIMARY KEY NOT NULL,
+  user_id INT(11) NOT NULL,
+  address VARCHAR(255) NOT NULL,
+  protocol VARCHAR(255) NOT NULL,
+  created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+  updated_at DATETIME,
+  FOREIGN KEY(user_id) REFERENCES user(id)
+);
+
+CREATE INDEX contact_idx_user_id ON contact (user_id);
+
+--
+-- Table: notification
+--
+DROP TABLE notification;
+
+CREATE TABLE notification (
+  id INTEGER PRIMARY KEY NOT NULL,
+  user_id INT(11),
+  persist INT(1),
+  event VARCHAR(255) NOT NULL,
+  condition TEXT NOT NULL,
+  comment VARCHAR(255),
+  created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+  updated_at DATETIME,
+  FOREIGN KEY(user_id) REFERENCES user(id)
+);
+
+CREATE INDEX notification_idx_user_id ON notification (user_id);
+
 --
 -- Table: reportgrouptestrunstats
 --
@@ -23,6 +59,19 @@ CREATE TABLE reportgrouptestrunstats (
   success_ratio VARCHAR(20)
 );
 
+--
+-- Table: notification_event
+--
+DROP TABLE notification_event;
+
+CREATE TABLE notification_event (
+  id INTEGER PRIMARY KEY NOT NULL,
+  message VARCHAR(255),
+  type VARCHAR(255),
+  created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+  updated_at DATETIME
+);
+
 --
 -- Table: reportsection
 --
@@ -49,6 +98,7 @@ CREATE TABLE reportsection (
   ticket_url VARCHAR(255),
   wiki_url VARCHAR(255),
   planning_id VARCHAR(255),
+  moreinfo_url VARCHAR(255),
   tags VARCHAR(255),
   xen_changeset VARCHAR(255),
   xen_hvbits VARCHAR(10),
@@ -131,7 +181,8 @@ CREATE TABLE report (
   machine_name VARCHAR(50) DEFAULT '',
   machine_description TEXT DEFAULT '',
   created_at DATETIME NOT NULL,
-  updated_at DATETIME NOT NULL
+  updated_at DATETIME NOT NULL,
+  FOREIGN KEY(suite_id) REFERENCES suite(id)
 );
 
 CREATE INDEX report_idx_suite_id ON report (suite_id);
@@ -149,8 +200,10 @@ CREATE TABLE reportfile (
   filename VARCHAR(255) DEFAULT '',
   contenttype VARCHAR(255) DEFAULT '',
   filecontent LONGBLOB NOT NULL DEFAULT '',
+  is_compressed INT NOT NULL DEFAULT 0,
   created_at DATETIME NOT NULL,
-  updated_at DATETIME NOT NULL
+  updated_at DATETIME NOT NULL,
+  FOREIGN KEY(report_id) REFERENCES report(id)
 );
 
 CREATE INDEX reportfile_idx_report_id ON reportfile (report_id);
@@ -164,7 +217,9 @@ CREATE TABLE reportgrouparbitrary (
   arbitrary_id VARCHAR(255) NOT NULL,
   report_id INT(11) NOT NULL,
   primaryreport INT(11),
-  PRIMARY KEY (arbitrary_id, report_id)
+  owner VARCHAR(255),
+  PRIMARY KEY (arbitrary_id, report_id),
+  FOREIGN KEY(report_id) REFERENCES report(id)
 );
 
 CREATE INDEX reportgrouparbitrary_idx_report_id ON reportgrouparbitrary (report_id);
@@ -178,7 +233,9 @@ CREATE TABLE reportgrouptestrun (
   testrun_id INT(11) NOT NULL,
   report_id INT(11) NOT NULL,
   primaryreport INT(11),
-  PRIMARY KEY (testrun_id, report_id)
+  owner VARCHAR(255),
+  PRIMARY KEY (testrun_id, report_id),
+  FOREIGN KEY(report_id) REFERENCES report(id)
 );
 
 CREATE INDEX reportgrouptestrun_idx_report_id ON reportgrouptestrun (report_id);
@@ -192,7 +249,8 @@ CREATE TABLE reporttopic (
   id INTEGER PRIMARY KEY NOT NULL,
   report_id INT(11) NOT NULL,
   name VARCHAR(50) DEFAULT '',
-  details TEXT NOT NULL DEFAULT ''
+  details TEXT NOT NULL DEFAULT '',
+  FOREIGN KEY(report_id) REFERENCES report(id)
 );
 
 CREATE INDEX reporttopic_idx_report_id ON reporttopic (report_id);
@@ -209,7 +267,8 @@ CREATE TABLE tap (
   tap_is_archive INT(11),
   tapdom LONGBLOB DEFAULT '',
   created_at DATETIME NOT NULL,
-  updated_at DATETIME NOT NULL
+  updated_at DATETIME NOT NULL,
+  FOREIGN KEY(report_id) REFERENCES report(id)
 );
 
 CREATE INDEX tap_idx_report_id ON tap (report_id);
@@ -226,7 +285,9 @@ CREATE TABLE reportcomment (
   succession INT(10),
   comment TEXT NOT NULL DEFAULT '',
   created_at DATETIME NOT NULL,
-  updated_at DATETIME NOT NULL
+  updated_at DATETIME NOT NULL,
+  FOREIGN KEY(report_id) REFERENCES report(id),
+  FOREIGN KEY(user_id) REFERENCES user(id)
 );
 
 CREATE INDEX reportcomment_idx_report_id ON reportcomment (report_id);
